-- KillSound - by StrayGenius, September 20 2014
KillSound         = {}
KillSound.name    = 'KillSound'
KillSound.version = 1.40

local LAM = LibStub("LibAddonMenu-2.0")

KillSound.Default = {
		  doText    = 3,
		  doPlay    = 2,
		  inChat    = false,
		  inGroup   = false,
		  OffsetX   = 0,
		  OffsetY   = 20,
		  dragMsg   = true,
}

function KillSound.Initialize()
	 KillSound.vars = ZO_SavedVars:New("KillSoundVars", KillSound.version, nil, KillSound.Default)

	 -- Clear the screen message
	 KillSoundLabel:SetText("")

	 -- Restore location
	 KillSoundWindow:ClearAnchors()
	 KillSoundWindow:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, KillSound.vars.OffsetX, KillSound.vars.OffsetY)

	 EVENT_MANAGER:UnregisterForEvent(KillSound.name, EVENT_ADD_ON_LOADED)
end

function KillSound.SaveXY()
	 KillSound.vars.OffsetX = KillSoundWindow:GetLeft()
	 KillSound.vars.OffsetY = KillSoundWindow:GetTop()
end

local killSounds = {
      [0] = "Click",
      [1] = "Click",
      [2] = "Emperor_Coronated_Daggerfall",
      [3] = "AvA_Gate_Opened",
      [4] = "SkillXP_BossKilled",
      [5] = "Raid_Trial_Failed",
      [6] = "Stats_Purchase",
      [7] = "Money_Transact",
}

function KillSound.Event(eventID,result,isError,abilityName,abilityGraphic,abilityActionSlotType,sourceName,sourceType,targetName,targetType,hitValue,powerType,damageType,log)
	 if (KillSound.vars == nil) then
	    return
         end

	 if (KillSound.vars.inGroup) then
	    if (GetGroupSize() <= 1) then
	       return
	    end
	 end

	 local killCode = math.floor(result/10) * 10
	 if (killCode ~= 2260) then return end
	 if (abilityName == nil) then return end

      	 local toonname = GetUnitName("player")
	 local attacker = SplitString("^", sourceName)
	 local defender = SplitString("^", targetName)

	 if (toonname ~= attacker) then return end
	 if (defender == nil) then return end

	 if (KillSound.vars.doPlay ~= 0) then 
	    PlaySound(killSounds[KillSound.vars.doPlay])
	 end
	 local mess = "Killed "..defender.." with "..abilityName
	 if (KillSound.vars.inChat) then d(mess) end
	 if (KillSound.vars.doText > 1 ) then
	    KillSoundLabel:SetText(mess)
	    KillSoundms = KillSound.vars.doText * 2000
	    zo_callLater(function() KillSoundLabel:SetText("") end, KillSoundms )
	 end
end

function KillSound.dragClear(eventCode, isHidden)
	 if (KillSound.vars == nil) then
	    return
         end

	 if (isHidden) then
	    return
	 end

	 if (KillSound.dragMsg) then
	     KillSoundLabel:SetText("")
	     KillSound.dragMsg = false
	 end
end

EVENT_MANAGER:RegisterForEvent(KillSound.name, EVENT_COMBAT_EVENT, KillSound.Event)
EVENT_MANAGER:RegisterForEvent(KillSound.name, EVENT_ADD_ON_LOADED, KillSound.Initialize)
EVENT_MANAGER:RegisterForEvent(KillSound.name, EVENT_RETICLE_HIDDEN_UPDATE, KillSound.dragClear)

local textOptions = {[0] = "Oops", [1] = "No displayed message", [2] = "2 second message", [3] = "4 second message", [4] = "6 second message",   [5] = "8 second message",  [6] = "10 second message",  [7] = "12 second message", }
local playOptions = {[0] = "Oops", [1] = "No sound",             [2] = "Triumphant Drums", [3] = "Metallic slam",    [4] = "Fanfare with drums", [5] = "Small gong", [6] = "Short drums", [7] = "Coins", }

local panelData = {
      type         = "panel",
      name         = KillSound.name,
      displayName  = "|cFF6544" .. KillSound.name,
      author       = "StrayGenius",
      version      = KillSound.version,
      slashCommand = "/killsound",
      registerForRefresh  = true,
      registerForDefaults = true,
}

local function getOption(optionTable,optionStg)
      for i=1,7 do
      	  if (optionTable[i] == optionStg) then
	     return i
	  end
      end
      return 0
end

local menuOptions = {
      [1] = {
      	  type = "header",
	  name = "Sound & message for killing blows",
	  },

	  [2] = {
	  type  = "description",
	  text  = "(displayed message is draggable)" 
	  },

	  [3] = {
      	  type    = "checkbox",
          name    = "KillSound only when grouped",
	  default = KillSound.Default.inGroup,
	  tooltip = "If checked, no sound or message unless you are grouped",
	  getFunc = function() return KillSound.vars.inGroup end,
	  setFunc = function(booval) KillSound.vars.inGroup = booval end,
	  },

	  [4] = {
      	  type    = "checkbox",
          name    = "Chat message",
	  default = KillSound.Default.inChat,
	  tooltip = "If a killing blow shows a message in chat",
	  getFunc = function() return KillSound.vars.inChat end,
	  setFunc = function(booval) KillSound.vars.inChat = booval end,
	  },

	  [5] = {
	  type    = "dropdown",
	  name    = "Display message",
	  default = textOptions[KillSound.Default.doText],
	  tooltip = "If killing blow has a display message and how many seconds",
	  choices = textOptions,
	  getFunc = function() if (KillSound.vars.doText > 1) then KillSoundLabel:SetText("KillSound Message (drag me)") KillSound.dragMsg = true end return textOptions[KillSound.vars.doText] end,
	  setFunc = function(opt) KillSound.vars.doText = getOption(textOptions,opt) if (KillSound.vars.doText > 1) then KillSoundLabel:SetText("KillSound Message (drag me)") KillSound.dragMsg = true else KillSoundLabel:SetText("") KillSound.dragMsg = false end end,
	  },

	  [6] = {
	  type    = "dropdown",
	  name    = "Killing blow plays sound",
	  default = playOptions[KillSound.Default.doPlay],
	  tooltip = "If a killing blow plays a sound",
	  choices = playOptions,
	  getFunc = function() if (KillSound.vars.doPlay > 1) then PlaySound(killSounds[KillSound.vars.doPlay]) end return playOptions[KillSound.vars.doPlay] end,
	  setFunc = function(opt) KillSound.vars.doPlay = getOption(playOptions,opt) if (KillSound.vars.doPlay > 1) then PlaySound(killSounds[KillSound.vars.doPlay]) end end,
	  },
}

LAM:RegisterAddonPanel("KillSoundMenu", panelData)
LAM:RegisterOptionControls("KillSoundMenu", menuOptions)
